pro rd_sxl, sttim, entim, index, data, infil=infil, summary=summary, new=new, old=old
;
;+
;NAME: 
;	rd_sxl
;PURPOSE:
;	Read the contents of the SXL data files (SXT X-Ray Log)
;CALLING SEQUENCE:
;	rd_sxl, '1-sep-91', '1-nov-91', index, data
;	rd_sxl, '1-dec-91', '1-jun-92', roadmap, /summary
;INPUT:
;	sttim	- start time in any format
;	entim	- end time in any format
;OPTIONAL KEYWORD INPUT:
;	infil	- The user can specify the input file name
;		  instead of the start/end times.  Must be a scalar.
;	summary - If set, just read the roadmaps of the times selected
;	new	- If set, read the .02 SXL files
;	old	- If set, read the .01 SXL files
;OUTPUT:
;	index	- the data index
;	data	- an array structure
;HISTORY:
;	Written 13-Aug-92 by M.Morrison
;	21-Apr-93 (MDM) - Modified to use STR_COPY_TAGS
;	 9-Jul-93 (MDM) - Added /NEW option
;	19-Aug-93 (MDM) - Added /OLD option
;			- Made the default to read the .02 files
;			 ---------------------------------------
;	15-Nov-93 (MDM) - Modified significantly to use RD_XDA instead of
;			  doing the reading within RD_SXL.
;	18-Nov-93 (MDM) - Corrected oversight - /SUMMARY option was not
;			  coded at all
;	10-Jan-2001 (GLS) - Added modulo operator to the file name construction to
;			    handle 3 or 4 digit years.
;-
;
qdebug = 1
exten = 'a.02'
if (keyword_set(old)) then exten = 'a.01'
;
if (not keyword_set(infil)) then begin
    weeks = week_loop(sttim, entim)
    files = 'sxl' + string(weeks.year mod 100, format='(i2.2)') + '_' + $
            string(weeks.week, format='(i2.2)') + exten
    files = concat_dir('$DIR_SXT_SXL', files)
    ss = where(file_exist(files), count)
    if (count eq 0) then begin
	print, 'RD_SXL: Cannot find the necessary files:'
	prstr, '   ' + files
	return
    end
    files = files(ss)
    rd_roadmap, files, roadmap
    if (get_nbytes(roadmap) lt 10) then return
    dsets = sel_timrange(roadmap, sttim, entim, /between)
    qinfil = 0
end else begin
    files = infil
    dsets = -1
    qinfil = 1
end
;
if (keyword_set(summary)) then begin
    rd_roadmap, files, index
    ss = sel_timrange(index, sttim, entim, /bet)
    if (ss(0) ne -1) then index = index(ss)
end else begin
    rd_xda, files, dsets, index, data
end
;
if (keyword_set(qstop)) then stop
end
